define(
//begin v1.x content
{
	"HKD_displayName": "hongkonški dolar",
	"CNY_displayName": "kitajski juan",
	"JPY_displayName": "japonski jen",
	"JPY_symbol": "¥",
	"USD_displayName": "ameriški dolar",
	"CAD_symbol": "CAD",
	"GBP_displayName": "britanski funt",
	"CHF_displayName": "švicarski frank",
	"CNY_symbol": "CN¥",
	"EUR_displayName": "evro",
	"GBP_symbol": "GBP",
	"CAD_displayName": "kanadski dolar",
	"USD_symbol": "$",
	"EUR_symbol": "€",
	"AUD_displayName": "avstralski dolar",
	"CHF_symbol": "CHF",
	"HKD_symbol": "HK$",
	"AUD_symbol": "AUD"
}
//end v1.x content
);